"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_linear_gradient_1 = tslib_1.__importDefault(require("react-native-linear-gradient"));
const styles = react_native_1.StyleSheet.create({
    container: {
        alignItems: 'center',
    },
    buttonContainer: {
        width: '100%',
        height: '100%',
        overflow: 'hidden',
    },
    button: {
        width: '100%',
        height: '100%',
        justifyContent: 'center',
    },
    title: {
        textAlign: 'center',
    },
    raised: {
        ...react_native_1.Platform.select({
            android: {
                elevation: 4,
            },
            default: {
                shadowColor: 'rgba(0,0,0, .4)',
                shadowOffset: { height: 1, width: 1 },
                shadowOpacity: 1,
                shadowRadius: 1,
            },
        }),
    },
    disabled: {
        backgroundColor: 'hsl(208, 8%, 90%)',
    },
});
class AnimatedLoadingButton extends react_1.PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            loading: false,
        };
        // We want to turn any percentages into a numeric width.
        this.containerWidth = 3000;
        // We want to turn any percentages into a numeric height.
        this.containerHeight = 3000;
        this.setLoading = (loading) => {
            const { duration } = this.props;
            if (loading) {
                this.animateButton(this.containerHeight, this.containerHeight / 2, 0);
                setTimeout(() => {
                    this.setState({ loading });
                }, duration);
            }
            else {
                this.animateButton(this.containerWidth, this.borderRadius, 1);
                this.setState({ loading });
            }
        };
        this.onLayout = (e) => {
            const { layout } = e.nativeEvent;
            const { loading } = this.state;
            this.containerWidth = layout.width;
            this.containerHeight = layout.height;
            if (!loading) {
                this.loadingValue.maxWidth.setValue(this.containerWidth);
            }
        };
        const { borderRadius } = props.buttonStyle;
        this.loadingValue = {
            maxWidth: new react_native_1.Animated.Value(this.containerWidth),
            borderRadius: new react_native_1.Animated.Value(borderRadius || 0),
            opacity: new react_native_1.Animated.Value(1),
        };
    }
    get borderRadius() {
        const { buttonStyle } = this.props;
        return buttonStyle.borderRadius || 0;
    }
    animateButton(maxWidthEnd, borderRadiusEnd, opacityEnd) {
        const { duration } = this.props;
        const { maxWidth, opacity, borderRadius } = this.loadingValue;
        react_native_1.Animated.timing(maxWidth, {
            toValue: maxWidthEnd,
            duration,
            useNativeDriver: false,
        }).start();
        react_native_1.Animated.timing(borderRadius, {
            toValue: borderRadiusEnd,
            duration,
            useNativeDriver: false,
        }).start();
        react_native_1.Animated.timing(opacity, {
            toValue: opacityEnd,
            duration,
            useNativeDriver: false,
        }).start();
    }
    renderLoading() {
        const { loadingStyle, loadingProps } = this.props;
        return (<react_native_1.ActivityIndicator style={loadingStyle} color={loadingStyle.color} {...loadingProps}/>);
    }
    renderTitle() {
        const { opacity } = this.loadingValue;
        const { title, titleStyle, titleProps } = this.props;
        return (<react_native_1.Animated.Text style={react_native_1.StyleSheet.flatten([styles.title, { opacity }, titleStyle])} {...titleProps}>
        {title}
      </react_native_1.Animated.Text>);
    }
    render() {
        const { loading } = this.state;
        const { containerStyle, TouchableComponent, onPress, buttonStyle, raised, disabled, disabledStyle, titleStyle, ...props } = this.props;
        const { maxWidth, borderRadius } = this.loadingValue;
        // The container will help calculate the layout width and height.
        // The animated view will help animate the restricted maxWidth, borderRadius.
        return (<react_native_1.View style={[styles.container, containerStyle]} onLayout={this.onLayout}>
        <react_native_1.Animated.View style={react_native_1.StyleSheet.flatten([
            styles.buttonContainer,
            {
                maxWidth,
                borderRadius,
            },
        ])}>
          <react_native_1.TouchableOpacity onPress={onPress} disabled={loading} delayPressIn={0} activeOpacity={0.3} accessibilityRole="button" 
        // accessibilityStates={[...(loading ? ['busy'] : [])]}
        // background={
        //   Platform.OS === 'android' && Platform.Version >= 21
        //     ? TouchableNativeFeedback.Ripple(
        //         titleStyle.color || 'white',
        //         false,
        //       )
        //     : undefined
        // }
        {...props}>
            <react_native_linear_gradient_1.default colors={['#0699FF', '#0D6CEC']} style={react_native_1.StyleSheet.flatten([
            styles.button,
            raised && styles.raised,
            buttonStyle,
            disabled && styles.disabled,
            disabled && disabledStyle,
        ])}>
              {loading ? this.renderLoading() : this.renderTitle()}
            </react_native_linear_gradient_1.default>
          </react_native_1.TouchableOpacity>
        </react_native_1.Animated.View>
      </react_native_1.View>);
    }
}
exports.default = AnimatedLoadingButton;
AnimatedLoadingButton.defaultProps = {
    containerStyle: {
        width: '100%',
        height: 50,
    },
    buttonStyle: {
        backgroundColor: '#424242',
        borderRadius: 4,
        paddingHorizontal: 16,
    },
    title: 'Button',
    titleStyle: {
        color: 'white',
    },
    titleProps: {},
    loadingStyle: {
        color: 'white',
    },
    loadingProps: {},
    TouchableComponent: react_native_1.Platform.select({
        android: react_native_1.TouchableNativeFeedback,
        default: react_native_1.TouchableOpacity,
    }),
    duration: 400,
    raised: false,
    disabled: false,
    disabledStyle: {},
    useNativeDriver: false,
};
//# sourceMappingURL=AnimatedLoadingButton.js.map